/*
 *  Created by Parag K. Mital - http://pkmital.com
 *  Contact: parag@pkmital.com
 *
 *  Copyright 2011 Parag K. Mital. All rights reserved.
 *
 *   Permission is hereby granted, free of charge, to any person
 *   obtaining a copy of this software and associated documentation
 *   files (the "Software"), to deal in the Software without
 *   restriction, including without limitation the rights to use,
 *   copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the
 *   Software is furnished to do so, subject to the following
 *   conditions:
 *
 *   The above copyright notice and this permission notice shall be
 *   included in all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 *   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 *   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 *   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *   OTHER DEALINGS IN THE SOFTWARE.
 */

#include "testApp.h"

#include "MyGuiController.h"

MyGuiController * myGuiController;

//--------------------------------------------------------------
void testApp::setup(){	
    // initialize the accelerometer
    ofxAccelerometer.setup();

    //iPhoneAlerts will be sent to this.
    ofxiPhoneAlerts.addListener(this);

    // dump lots of info to console (useful for debugging)
    ofSetLogLevel(OF_LOG_VERBOSE);
    
    // open the mapview
    mapKit.open();
	
    coreLocation = new ofxiPhoneCoreLocation();
    bHasCompass = coreLocation->startHeading();
    bHasGPS = coreLocation->startLocation();
    
    if (bHasGPS) {
        mapKit.setRegionWithMeters(coreLocation->getLatitude(), 
                                   coreLocation->getLongitude(), 
                                   1000, 
                                   1000);
    }
    else {
        // set initial position to specified coordinates, and cover 1000 Km x 1000 Km area
        mapKit.setRegionWithMeters(40, -74, 1000, 1000);
    }

    // add testApp as a listener for map event (callbacks below)
    // (don't really need this for this example. we could remove all the mapkit related
    // callbacks then.)
    mapKit.addListener(this);
	
    // set other optional parameters
    mapKit.setShowUserLocation(true);
    mapKit.setType(OFXIPHONE_MAPKIT_HYRBID);
    //	mapKit.setAllowZoom(false);
    //	mapKit.setAllowScroll(false);
    //	mapKit.setAllowUserInteraction(false);

    // send the OpenGL View to the front (on top of the mapview)
    ofxiPhoneSendGLViewToFront();

    // OpenGL View is now in front of mapview, but it isn't transparent, so we can't see the map
    // Make the map transparent so we can see the mapview in undrawn areas
    ofxiPhoneSetGLViewTransparent(true);

    // Now that the OpenGL view is in front of the mapview, it will receive all the touch events, so we cannot interact with the map
    // So disable interaction with the OpenGL view (testApp::touchXXXXX will not be called)
    ofxiPhoneSetGLViewUserInteraction(false);

    picker.setMaxDimension(480);
    
    // Our Gui setup which holds the "Take Photo" button
    myGuiController	= [[MyGuiController alloc] initWithNibName:@"View" bundle:nil];
    [ofxiPhoneGetUIWindow() addSubview:myGuiController.view];
    
    // Make sure our OpenGL View is see-through
    ofEnableAlphaBlending();
    ofBackground(0,0,0,0);
}


//--------------------------------------------------------------
void testApp::update() {
    if(mapKit.isOpen()) {
        //		printf("User is %son screen\n", mapKit.isUserOnScreen() ? "" : "not ");
        if (bHasGPS) {
            
        }
        else {
            // set initial position to specified coordinates, and cover 1000 Km x 1000 Km area
            mapKit.setRegionWithMeters(40, -74, 1000, 1000);
        }
    }
}

//--------------------------------------------------------------
void testApp::draw() {
}

void testApp::recordAudio() {
    printf("record audio button pushed\n");
}

void testApp::takePhoto() {
    picker.openCamera();
}

void testApp::centerMap() {
    if (bHasGPS) {
        mapKit.setCenter(coreLocation->getLatitude(), 
                         coreLocation->getLongitude());
    }
}

void testApp::regionWillChange(bool animated) {
    //	printf("testApp::regionWillChange | animated: %i\n", animated);
}

void testApp::regionDidChange(bool animated) {
    //	printf("testApp::regionDidChange | animated: %i\n", animated);
}

void testApp::willStartLoadingMap() {
    //	printf("testApp::willStartLoadingMap\n");
}

void testApp::didFinishLoadingMap() {
    //	printf("testApp::didFinishLoadingMap\n");
}

void testApp::errorLoadingMap(string errorDescription) {
    //	printf("testApp::errorLoadingMap : %s\n", errorDescription.c_str());
}

//--------------------------------------------------------------
void testApp::exit() {
}

//--------------------------------------------------------------
void testApp::lostFocus() {
}

//--------------------------------------------------------------
void testApp::gotFocus() {
}

//--------------------------------------------------------------
void testApp::gotMemoryWarning() {
}

//--------------------------------------------------------------
void testApp::deviceOrientationChanged(int newOrientation){
}


